Name:           med
Version:        4.1.0
Release:        %mkrel 1
Summary:        Library to exchange meshed data
Group:          System/Libraries
License:        LGPLv3+
# This URL is no longer available
URL:            https://www.salome-platform.org/user-section/about/med
Source0:        https://files.salome-platform.org/Salome/other/%{name}-%{version}.tar.gz

# Chars are unsigned on arm, but the tests do not appear to expect this
# Patch generated via
#    find . -type f -print0 | xargs -0 sed -i "s|-e 's/H5T_STD_I8LE//g'|-e 's/H5T_STD_I8LE//g' -e 's/H5T_STD_U8LE//g'|g"
#Patch0:         med_tests.patch
# - Install headers in %%_includedir/med
# - Use LIB_SUFFIX
# - Install cmake config files to %%_libdir/cmake
# - Install doc to %%_pkgdocdir
Patch1:         med_cmake.patch

Patch2:         https://src.fedoraproject.org/rpms/med/raw/rawhide/f/med-hdf5-1.12.patch

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-gfortran
BuildRequires:  hdf5-devel >= 1.12.2
BuildRequires:  hdf5 >= 1.10.2
BuildRequires:  python3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(zlib)

# For autoreconf
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool


%description
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Requires:       %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3-%{name} package contains python3 bindings for %{name}.


%package        tools
Summary:        Runtime tools for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       tk

%description    tools
This package contains runtime tools for %{name}:
  - mdump: a tool to dump MED files
  - xmdump: graphical version of mdump.
  - medconforme: a tool to validate a MED file
  - medimport: a tool to convert a MED v2.1 or v2.2 file into a MED v2.3 file


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       cmake

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

# ease upgrade mga7->mga8
Conflicts:      med < 3.3.1-7

%description    doc
The %{name}-doc package contains the documentation for %{name}.


%prep
%autosetup -p1 -n %{name}-%{version}

# Fix file not utf8
iconv --from=ISO-8859-1 --to=UTF-8 ChangeLog > ChangeLog.new && \
touch -r ChangeLog ChangeLog.new && \
mv ChangeLog.new ChangeLog


%build
%cmake \
    -DMEDFILE_BUILD_PYTHON=1 \
    -DPYTHON_EXECUTABLE=%{__python3} \
    -DPYTHON_INCLUDE_DIR=%{_includedir}/python%{python3_version}$(python3-config --abiflags)/ \
    -DPYTHON_LIBRARY=%{_libdir}/libpython%{python3_version}$(python3-config --abiflags).so  .
%cmake_build

%install
%cmake_install

# Remove test-suite files
rm -rf %{buildroot}%{_bindir}/testc
rm -rf %{buildroot}%{_bindir}/testf
rm -rf %{buildroot}%{_bindir}/testpy

%check
ctest -V || :

%files
%doc AUTHORS ChangeLog  README
%license COPYING.LESSER
%{_libdir}/libmed.so.1*
%{_libdir}/libmedC.so.1*
%{_libdir}/libmedimport.so.0*
%{_libdir}/libmedfwrap.so.11*

%files -n python3-%{name}
%{python3_sitearch}/%{name}/

%files tools
%{_bindir}/*mdump*
%{_bindir}/medconforme
%{_bindir}/medimport

%files devel
%{_libdir}/*.so
%{_libdir}/cmake/MEDFile/
%{_includedir}/%{name}/

%files doc
%license COPYING.LESSER
%doc %{_pkgdocdir}


%changelog
* Mon Dec 05 2022 kekepower <kekepower> 4.1.0-1.mga9
+ Revision: 1918008
- Update to version 4.1.0
- Add patch from Fedora to build with hdf5-1.12

* Fri Apr 01 2022 umeabot <umeabot> 4.0.0-8.mga9
+ Revision: 1837840
- Mageia 9 Mass Rebuild
+ tv <tv>
- Rebuild for python-3.10

* Wed Apr 21 2021 daviddavid <daviddavid> 4.0.0-6.mga9
+ Revision: 1717709
- rebuild for python 3.9

* Mon Jan 11 2021 daviddavid <daviddavid> 4.0.0-5.mga8
+ Revision: 1671095
- add conflicts to ease upgrade mga7->mga8

* Tue Oct 20 2020 eatdirt <eatdirt> 4.0.0-4.mga8
+ Revision: 1637372
- Fix unexistent BuildRequires

* Sun Feb 16 2020 umeabot <umeabot> 4.0.0-3.mga8
+ Revision: 1531391
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Sep 11 2019 wally <wally> 4.0.0-2.mga8
+ Revision: 1439775
- rebuild for python3.8

* Sat Jul 27 2019 kekepower <kekepower> 4.0.0-1.mga8
+ Revision: 1424548
- Update to version 4.0.0

* Mon Jan 07 2019 kekepower <kekepower> 3.3.1-6.mga7
+ Revision: 1351278
- Remove invalid Requires for cmake-filesystem

* Mon Jan 07 2019 kekepower <kekepower> 3.3.1-5.mga7
+ Revision: 1351018
- Rebuild for Python 3.7

* Sun Jan 06 2019 kekepower <kekepower> 3.3.1-4.mga7
+ Revision: 1350055
- Package med-devel requires hdf5_10

* Sun Jan 06 2019 kekepower <kekepower> 3.3.1-3.mga7
+ Revision: 1349989
- Requires hdf5_10

* Sat Jan 05 2019 kekepower <kekepower> 3.3.1-2.mga7
+ Revision: 1349947
- Requires libhdf5_10_10

* Sat Jan 05 2019 kekepower <kekepower> 3.3.1-1.mga7
+ Revision: 1349526
- imported package med

